@@ -7,6 +7,7 @@
 (in-package #:irc-logger)
 
 (defvar *daemon-monitor-process* nil "Process of background monitor.")
+(defparameter *timeout* 60)
 
 (defclass channel ()
   ((name :initarg :name :reader c-name
@@ -66,6 +67,10 @@
 		  :documentation
 		  "Time of last, potentially active, warning message.")))
 
+(defmethod print-object ((obj logger) stream)
+  (print-unreadable-object (obj stream :type t :identity t)
+    (format stream "~A" (l-nickname obj))))
+
 (defvar *loggers* nil "List of active loggers.")
 
 (defparameter *user-address-scanner*
@@ -141,6 +146,9 @@
 (defmethod log-file-path (output-root channel-name year month day (format (eql :sexp)))
   (%log-file-path output-root channel-name year month day "sexp"))
 
+(defmethod log-file-path (output-root channel-name year month day (format (eql :binary)))
+  (%log-file-path output-root channel-name year month day "bin"))
+
 (defmethod log-file-path (output-root channel-name year month day (format (eql :text)))
   (%log-file-path output-root channel-name year month day "txt"))
 
@@ -372,7 +380,11 @@
 	   (apply #'format nil fmt args)))))
 
 (defun add-private-log-entry (logger fmt &rest args)
-  (apply #'add-log-entry (get-private-log-stream logger) fmt args))
+  (apply #'add-log-entry
+	 (if (get-private-log-stream logger) 
+	     (get-private-log-stream logger) 
+	     *standard-output*)
+	 fmt args))
 
 (defun privmsg-hook (msg)
   (let ((logger (find-logger-with-connection (connection msg)))
@@ -626,13 +638,31 @@
     (add-private-log-entry (find-logger-with-nick nick)
 			   "Closing previously active connection [add-logger].")
     (ignore-errors (remove-logger nick)))
-  (let ((logger (create-logger nick server :channels channels :output output
-			       :logging-stream logging-stream :password password
-			       :realname realname :username username
-			       :private-log private-log 
-			       :unknown-log unknown-log 
-			       :formats formats
-			       :async async)))
+  (add-private-log-entry nil "Calling create-logger [add-logger].~%")
+  (let ((logger
+	 (do ((new-logger 
+	       (mp:with-timeout (*timeout* nil)
+		 (create-logger nick server :channels channels :output output
+				:logging-stream logging-stream :password password
+				:realname realname :username username
+				:private-log private-log 
+				:unknown-log unknown-log 
+				:formats formats
+				:async async))
+	       (mp:with-timeout (*timeout* nil)
+		 (create-logger nick server :channels channels :output output
+				:logging-stream logging-stream :password password
+				:realname realname :username username
+				:private-log private-log 
+				:unknown-log unknown-log 
+				:formats formats
+				:async async))))
+	     (new-logger 
+	      (progn
+		(add-private-log-entry nil "Acquired new logger ~A." new-logger)
+		new-logger))
+	   (add-private-log-entry nil "Timeout trying to create new logger [add-logger]."))))
+    (add-private-log-entry logger "Pushing newly created logger ~A [add-logger].~%" logger)
     (push logger *loggers*)
     (start-logger logger async)
     logger))
@@ -718,7 +748,6 @@
 (defun is-connected (logger)
   (%is-connected logger))
 
-(defparameter *timeout* 60)
 
 (defun is-connected (logger)
   #-allegro (%is-connected logger)
@@ -785,8 +814,7 @@
 	(sleep 5)
 	(when (is-connected new-logger)
 	  (log-reconnection new-logger)))))
-      
-  )
+  ) ;; end closure
 
 (defun daemon-monitor ()
   "This function runs in the background and monitors the connection of the logger."
